#! /usr/bin/env python
# -*- coding: utf-8 -*-

print(u'\xA9')

